@@ -8,6 +8,8 @@
 #include "filter/filtermanager.h"
 #include "widgets/profilebrowser.h"
 #include "widgets/albuminfowidget.h"
+#include "widgets/photolistwidget.h"
+#include "widgets/albumlistwidget.h"
 
 #include "config.h"
 
@@ -94,6 +96,14 @@ ImageBrowserPanel::~ImageBrowserPanel()
 
 void ImageBrowserPanel::init()
 {
+    // Create album list
+    listAlbums = new AlbumListWidget(sm);
+    ui->layoutAlbums->addWidget(listAlbums);
+
+    // Create photo list
+    listPhotos = new PhotoListWidget(sm);
+    ui->layoutPhotos->addWidget(listPhotos);
+
     // Title labels
     QLabel* friendLabel = new QLabel();
     friendLabel->setPixmap(QIcon(":/res/general_contacts.png").pixmap(ICON_SIZE));
@@ -129,7 +139,7 @@ void ImageBrowserPanel::init()
 
     connect(this->albumsTopPanel, SIGNAL(clicked()), this, SLOT(showFriendInfo()));
 
-    this->ui->listAlbums->setFont(this->usedFont);
+    this->listAlbums->setFont(this->usedFont);
     this->albumsTopPanel->setFont(this->usedFont);
 
     // Profile info widget (ProfileBrowser) for albums top panel
@@ -150,8 +160,7 @@ void ImageBrowserPanel::init()
     this->photosTopPanel->setBackIcon(QIcon::fromTheme("general_back",
                                                        QIcon(":/res/general_back.png")));
 
-    ui->listPhotos->setDragDropMode(QAbstractItemView::NoDragDrop);
-    this->ui->listPhotos->setFont(this->usedFont);
+    this->listPhotos->setFont(this->usedFont);
     this->photosTopPanel->setFont(this->usedFont);
 
     // Album info widget for photos top panel
@@ -171,9 +180,9 @@ void ImageBrowserPanel::init()
     // signals
     connect(this->friendsPanel, SIGNAL(ownerSelected(Friend)),
             this, SLOT(ownrSelected(Friend)));
-    connect(ui->listAlbums, SIGNAL(itemClicked(QListWidgetItem*)),
+    connect(listAlbums, SIGNAL(itemClicked(QListWidgetItem*)),
             this, SLOT(albmSelected(QListWidgetItem*)));
-    connect(ui->listPhotos, SIGNAL(itemClicked(QListWidgetItem*)),
+    connect(listPhotos, SIGNAL(itemClicked(QListWidgetItem*)),
             this, SLOT(photoSelected(QListWidgetItem*)));
     connect(buttonRefreshFriends, SIGNAL(clicked()),
             this, SLOT(refreshFriends()));
@@ -188,7 +197,7 @@ void ImageBrowserPanel::init()
             this, SLOT(hidePhotos()));
 
     // enable sorting
-    this->ui->listAlbums->setSortingEnabled(true);
+    this->listAlbums->setSortingEnabled(true);
 
     // device rotation
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
@@ -259,7 +268,7 @@ void ImageBrowserPanel::albmSelected(QListWidgetItem *item)
     this->setState(WindowPhotoAlbum);
 
     if (!isPhotosWidthSet) {
-        photosWidth = ui->listPhotos->viewport()->rect().width() - 18;
+        photosWidth = listPhotos->viewport()->rect().width() - 18;
         this->isPhotosWidthSet = true;
     }
 
@@ -487,24 +496,24 @@ void ImageBrowserPanel::updateListAlbums(Friend owner, AlbumList list, bool isLa
 
     if (list.isEmpty()) {
         qDebug() << "Empty album list for " << owner.ownerId() << "!!!!!!";
-        ui->listAlbums->clear();
+        listAlbums->clear();
         if (isLastUpdate)
-            new QListWidgetItem(tr("No albums"), ui->listAlbums); //QListWidgetItem *item2 = new
+            new QListWidgetItem(tr("No albums"), listAlbums); //QListWidgetItem *item2 = new
         else
-            new QListWidgetItem(tr("Download albums"), this->ui->listAlbums);
-        ui->listAlbums->setDisabled(true);
+            new QListWidgetItem(tr("Download albums"), this->listAlbums);
+        listAlbums->setDisabled(true);
         return;
     }
 
-    ui->listAlbums->setDisabled(false);
+    listAlbums->setDisabled(false);
 
     QList<QListWidgetItem *> delItems;
     AlbumList newAlbums;
     newAlbums.append(list);
 
     // search new albums in list of widgets
-    for (int i = 0; i < this->ui->listAlbums->count(); i++) {
-        QListWidgetItem *item = this->ui->listAlbums->item(i);
+    for (int i = 0; i < this->listAlbums->count(); i++) {
+        QListWidgetItem *item = this->listAlbums->item(i);
         QVariant v = item->data(Qt::UserRole);
 
         bool isFound = false;
@@ -540,15 +549,15 @@ void ImageBrowserPanel::updateListAlbums(Friend owner, AlbumList list, bool isLa
             delItems.append(item);
     }
 
-    qDebug() << "Will be add " << newAlbums.length() << " albums and removed " << delItems.length() << " records. Total widgets: " << ui->listAlbums->count();
+    qDebug() << "Will be add " << newAlbums.length() << " albums and removed " << delItems.length() << " records. Total widgets: " << listAlbums->count();
 
     // add new albums
     for (int i = 0; i < newAlbums.length(); i++) {
-        //QListWidgetItem *item = new QListWidgetItem(str, ui->listAlbums);
+        //QListWidgetItem *item = new QListWidgetItem(str, listAlbums);
         //item->setIcon(QIcon(list[i]->icon));
         //if (item->icon().isNull())
         //    item->setIcon(QPixmap(":/res/ms.png"));
-        QListWidgetItem *albumitem = new QListWidgetItem(ui->listAlbums);
+        QListWidgetItem *albumitem = new QListWidgetItem(listAlbums);
         albumitem->setIcon(QIcon(this->albumIcon(newAlbums.at(i))));
 
         albumitem->setData(Qt::DisplayRole, this->albumItem(newAlbums.at(i)));
@@ -569,8 +578,8 @@ void ImageBrowserPanel::updateListAlbums(Friend owner, AlbumList list, bool isLa
     }
 
     // update photo header
-    if (this->ui->listAlbums->selectedItems().length() > 0) {
-        QVariant v = this->ui->listAlbums->selectedItems().at(0)->data(Qt::UserRole);
+    if (this->listAlbums->selectedItems().length() > 0) {
+        QVariant v = this->listAlbums->selectedItems().at(0)->data(Qt::UserRole);
         Album al = v.value<Album>();
         this->setPhotoHeader(al);
     }
@@ -583,7 +592,7 @@ void ImageBrowserPanel::updateListPhotos(QString accountId, QString ownerId, QSt
 
     // check correctness that list was return for selected photo list
     bool isFoundSelectedAlbum = false;
-    QList<QListWidgetItem *> selItems = ui->listAlbums->selectedItems();
+    QList<QListWidgetItem *> selItems = listAlbums->selectedItems();
     for (int i = 0; i < selItems.length(); i++) {
         QVariant v = selItems[i]->data(Qt::UserRole);
         if (v.canConvert<Album>()) {
@@ -607,24 +616,24 @@ void ImageBrowserPanel::updateListPhotos(QString accountId, QString ownerId, QSt
     }
 
     if (list.isEmpty()) {
-        this->ui->listPhotos->clear();
+        this->listPhotos->clear();
         if (isLastUpdate)
-            new QListWidgetItem(tr("No images"), ui->listPhotos);
+            new QListWidgetItem(tr("No images"), listPhotos);
         else
-            new QListWidgetItem(tr("Download images"), this->ui->listPhotos);
-        ui->listPhotos->setDisabled(true);
+            new QListWidgetItem(tr("Download images"), this->listPhotos);
+        listPhotos->setDisabled(true);
         return;
     }
 
-    ui->listPhotos->setDisabled(false);
+    listPhotos->setDisabled(false);
 
     QList<QListWidgetItem *> delItems;
     PhotoList newPhoto;
     newPhoto.append(list);
 
     // search new images in list of widgets
-    for (int i = 0; i < this->ui->listPhotos->count(); i++) {
-        QListWidgetItem *item = this->ui->listPhotos->item(i);
+    for (int i = 0; i < this->listPhotos->count(); i++) {
+        QListWidgetItem *item = this->listPhotos->item(i);
         QVariant v = item->data(Qt::UserRole);
 
         bool isFound = false;
@@ -641,7 +650,7 @@ void ImageBrowserPanel::updateListPhotos(QString accountId, QString ownerId, QSt
 
                     QPixmap icon = this->photoIcon(curPhoto);
                     item->setIcon(QIcon(icon));
-                    //((QAbstractItemView*)this->ui->listPhotos)->setIconSize(icon.size());
+                    //((QAbstractItemView*)this->listPhotos)->setIconSize(icon.size());
 
                     v.setValue(curPhoto);
                     item->setData(Qt::UserRole, v);
@@ -661,12 +670,12 @@ void ImageBrowserPanel::updateListPhotos(QString accountId, QString ownerId, QSt
         if (!isFound)
             delItems.append(item);
     }
-    this->ui->listPhotos->setUpdatesEnabled(false);
+    this->listPhotos->setUpdatesEnabled(false);
 
     // add new photos
     for (int i = 0; i < newPhoto.length(); i++) {
         qDebug() << "Show photo_thumb: " << newPhoto.at(i).photoId();
-        QListWidgetItem *item = new QListWidgetItem(NULL, ui->listPhotos);
+        QListWidgetItem *item = new QListWidgetItem(NULL, listPhotos);
         QPixmap icon = this->photoIcon(newPhoto.at(i));
         item->setIcon(QIcon(icon));
         QVariant v;
@@ -678,9 +687,9 @@ void ImageBrowserPanel::updateListPhotos(QString accountId, QString ownerId, QSt
     for (int i = 0; i < delItems.length(); i++)
         delete delItems.at(i);
 
-    ((QAbstractItemView*)this->ui->listPhotos)->setIconSize(QSize(IMAGE_SIZE, IMAGE_SIZE));
-    this->ui->listPhotos->setUpdatesEnabled(true);
-    this->ui->listPhotos->repaint();
+    ((QAbstractItemView*)this->listPhotos)->setIconSize(QSize(IMAGE_SIZE, IMAGE_SIZE));
+    this->listPhotos->setUpdatesEnabled(true);
+    this->listPhotos->repaint();
 }
 
 void ImageBrowserPanel::refreshFriends()
@@ -733,7 +742,7 @@ void ImageBrowserPanel::refreshPhotos()
 void ImageBrowserPanel::refreshPhotos(bool isNeedUpdate)
 {
     qDebug() << __FILE__ <<":"<< __LINE__ << ":" << __FUNCTION__<<"()";
-    QListWidgetItem *item = this->ui->listAlbums->currentItem();
+    QListWidgetItem *item = this->listAlbums->currentItem();
     if (item == NULL) {
         qWarning() << __FILE__ <<":"<< __LINE__ << ":" << "unknown selected item";
         return;
@@ -902,7 +911,7 @@ void ImageBrowserPanel::orientationChanged()
     else
         this->isPortraitMode = true;
     this->setState();
-    this->ui->listPhotos->repaint();
+    this->listPhotos->repaint();
 }
 
 void ImageBrowserPanel::showFriendInfo()
@@ -949,10 +958,10 @@ void ImageBrowserPanel::gotError(QString, QTransport::Action action, bool)
         {
             this->isAlbumsUpdate = false;
             this->albumsTopPanel->setRefreshIcon(QIcon::fromTheme("general_refresh", QIcon(":/res/general_refresh.png")));
-            if (ui->listAlbums->count() == 0 || ui->listAlbums->item(0)->text().compare(tr("Download albums")) == 0) {
-                ui->listAlbums->clear();
-                new QListWidgetItem(tr("No albums"), ui->listAlbums); //QListWidgetItem *item2 = new
-                ui->listAlbums->setDisabled(true);
+            if (listAlbums->count() == 0 || listAlbums->item(0)->text().compare(tr("Download albums")) == 0) {
+                listAlbums->clear();
+                new QListWidgetItem(tr("No albums"), listAlbums); //QListWidgetItem *item2 = new
+                listAlbums->setDisabled(true);
             }
         } else {
             this->isAlbumsUpdate = true;
