@@ -9,8 +9,10 @@ class QMessageListModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
+    enum { SortRole = Qt::UserRole + 1 };
+
     explicit QMessageListModel(QObject *parent = 0):
-        QAbstractListModel(parent) {};
+        QAbstractListModel(parent) {}
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     int columnCount(const QModelIndex &parent = QModelIndex()) const;
@@ -18,10 +20,6 @@ public:
     QVariant headerData(int section, Qt::Orientation orientation,
                         int role = Qt::DisplayRole) const;
 
-    void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
-
-    void setNameFilter(const QString &str);
-
     QModelIndex getIndex(const Message& msg) const;
     QModelIndex getIndex(int column, const Message& msg) const;
     QModelIndex getIndex(const QString& accountId, const QString& messageId) const;
@@ -40,10 +38,6 @@ signals:
 
 private:
     MessageList shownMessagesList;
-
-    QString nameFilter;
-
-    void updateShownMessagesList();
 };
 
 #endif // QMESSAGELISTMODEL_H
